==> amaya-src-3.2.tgz: Amaya/thotlib/include/wininclude.h <==
#ifndef _WIN_FCT_
#define _WIN_FCT_
#include <windows.h>
#include "fileaccess.h"

#ifdef __STDC__
extern void       DropFile (Document, View, STRING);
extern HMENU      WIN_GetMenu (int);
extern void       WinErrorBox (ThotWindow, STRING);
extern void       WinLoadGC (HDC, int, int);
extern HFONT      WinLoadFont (HDC, ptrfont);
extern int        WIN_InitSystemColors ();
extern void       WIN_GetDeviceContext (int);
extern void       WIN_ReleaseDeviceContext ();
extern BOOL       WIN_TtaInitDialogue (CHAR_T*);
extern void       WIN_TtaSetPulldownOff (int, ThotMenu, ThotWindow);
extern void       WIN_TtaSetPulldownOn (int, ThotMenu, ThotWindow);
extern void       WIN_TtaSetToggleMenu (int, int, ThotBool, ThotWindow);
extern void       WIN_APP_TextCallback (ThotWindow, int);
extern void       WIN_ThotCallBack (ThotWindow, WPARAM, LPARAM);
extern void       WIN_CharTranslation (ThotWindow, int, UINT, WPARAM, LPARAM);
extern void       WIN_InitDialogueFonts (HDC, CHAR_T*);
extern void       APP_ButtonCallback (ThotButton, int, caddr_t);
extern void       CleanFrameCatList (int);
extern int        GetMainFrameNumber (ThotWindow);
extern LRESULT    ToolBarNotify (int, ThotWindow, WPARAM, LPARAM);
extern int        GetFrameNumber (ThotWindow);
extern void       TtaHandleOneWindowEvent (MSG*);
extern void       CreateOpenImgDlgWindow (ThotWindow parent, STRING imgName, int doc_select, int dir_select, int doc_type);
extern void       WIN_ListSaveDirectory (int, STRING, STRING);
extern void       ThotCallback (int, int, STRING data);
extern void       WIN_TtaSwitchButton (Document, View, int, int, int, BOOL);
extern void       SwitchIconMath (Document, View, ThotBool);
extern void       AddMathButton (Document, View);
extern int        TtaGetMessageTable (CONST CHAR_T*, int msgNumber);
extern int        GetWindowNumber (Document, View view);
extern void       TtaError (int);
extern void       CreateMCHARDlgWindow (ThotWindow parent, STRING math_entity_name) ;
extern void       CreateMathDlgWindow (ThotWindow parent);
extern void       CreateTableDlgWindow (int num_cols, int num_rows, int t_border);
extern void       CreateMatrixDlgWindow (int num_cols, int num_rows);
extern HDC        PASCAL GetPrinterDC (void);
extern void       ReusePrinterDC (void);
extern void       WinInitPrinterColors (void);
extern void       CreateAltDlgWindow ();
extern void       CreateCSSDlgWindow (ThotWindow parent, int nb_item, STRING buffer, STRING title, CHAR_T* msg_text);
extern void       CreateTextDlgWindow (ThotWindow parent, STRING attrHref);
extern void       CreateHelpDlgWindow (ThotWindow, STRING, STRING, STRING);
extern void       CreatePrintDlgWindow (ThotWindow parent, STRING ps_dir);
extern void       CreateAlign1DlgWindow (ThotWindow, int);
extern void       CreateAlign2DlgWindow (ThotWindow, int);
extern void       CreateAlign3DlgWindow (ThotWindow, int);
extern void       CreateSearchDlgWindow (ThotWindow, BOOL, CHAR_T*);
extern void       CreateSaveAsDlgWindow (ThotWindow parent, STRING path_name);
extern void       CreateOpenDocDlgWindow (ThotWindow parent, STRING title, STRING docName, int doc_select, int dir_select, int doc_type);
extern void       CreateGraphicsDlgWindow (int, int, int, ThotWindow);
extern void       CreateSaveListDlgWindow (ThotWindow parent, int nb_item, STRING save_list);
extern void       CreateCloseDocDlgWindow (ThotWindow parent, STRING msg, ThotBool* save_befor, ThotBool* close_dont_save);
extern void       CreateLanguageDlgWindow (ThotWindow, STRING, STRING, int, STRING, STRING, int, STRING);
extern void       CreateCharacterDlgWindow (ThotWindow, int, int, int, int, int);
extern void       CreateAttributeDlgWindow (STRING, int, int);
extern void       CreateRuleDlgWindow (ThotWindow parent, int nb_class, STRING class_list);
extern void       CreateApplyClassDlgWindow (ThotWindow parent, int nb_class, STRING class_list);
extern void       CreateSpellCheckDlgWindow (ThotWindow, STRING, STRING, int, int, int, int, int, int, int);
extern void       CreateMathAttribDlgWindow (int);
extern void       CreateInitConfirmDlgWindow (ThotWindow, int, STRING, STRING);
extern void       CreateInitConfirm3LDlgWindow (ThotWindow, int, STRING, STRING, STRING, STRING);
extern void       CreateChangeFormatDlgWindow (int, int, int, int, int, int, int, int);
extern void       CreateGreekKeyboardDlgWindow (ThotWindow);
extern void       CreateAuthenticationDlgWindow (ThotWindow, STRING, STRING);
extern void       CreateBackgroundImageDlgWindow (ThotWindow parent, int form_background, int image_URL, int image_label, int image_dir, int image_sel, int repeat_image, STRING image_location);
extern void       TtaHandleOneEvent (ThotEvent*);
extern ThotWindow TtaGetThotWindow (int);
extern BinFile    TtaReadOpen (CONST CHAR_T*);
extern ThotWindow GetCurrentWindow ();
extern void       WIN_DisplayWords (void);
extern void       KbdCallbackHandler (ThotWidget, int, caddr_t);
extern void       CheckTtCmap ();

#else  /* __STDC__ */
extern void       DropFile ();
extern HMENU      WIN_GetMenu ();
extern void       WinErrorBox ();
extern void       WinLoadGC ();
extern HFONT      WinLoadFont ();
extern int        WIN_InitSystemColors ();
extern void       WIN_GetDeviceContext ();
extern void       WIN_ReleaseDeviceContext ();
extern BOOL       WIN_TtaInitDialogue ();
extern void       WIN_TtaSetPulldownOff ();
extern void       WIN_TtaSetPulldownOn ();
extern void       WIN_TtaSetToggleMenu ();
extern void       WIN_APP_TextCallback ();
extern void       WIN_ThotCallBack ();
extern void       WIN_CharTranslation ();
extern void       WIN_InitDialogueFonts ();
extern void       APP_ButtonCallback ();
extern void       CleanFrameCatList ();
extern int        GetMainFrameNumber ();
extern LRESULT    ToolBarNotify ();
extern int        GetFrameNumber ();
extern void       TtaHandleOneWindowEvent ();
extern void       CreateOpenImgDlgWindow ();
extern void       CreateTableDlgWindow ();
extern void       WIN_ListSaveDirectory ();
extern void       ThotCallback ();
extern void       WIN_TtaSwitchButton ();
extern void       SwitchIconMath ();
extern void       AddMathButton ();
extern int        TtaGetMessageTable ();
extern int        GetWindowNumber (Document, View);
extern void       TtaError ();
extern void       CreateMatrixDlgWindow ();
extern HDC        PASCAL GetPrinterDC ();
extern void       ReusePrinterDC ();
extern void       WinInitPrinterColors ();
extern void       CreateAltDlgWindow ();
extern void       CreateCSSDlgWindow ();
extern void       CreateTextDlgWindow ();
extern void       CreateHelpDlgWindow ();
extern void       CreatePrintDlgWindow ();
extern void       CreateAlign1DlgWindow ();
extern void       CreateAlign2DlgWindow ();
extern void       CreateAlign3DlgWindow ();
extern void       CreateSearchDlgWindow ();
extern void       CreateSaveAsDlgWindow ();
extern void       CreateOpenDocDlgWindow ();
extern void       CreateGraphicsDlgWindow ();
extern void       CreateSaveListDlgWindow ();
extern void       CreateCloseDocDlgWindow ();
extern void       CreateLanguageDlgWindow ();
extern void       CreateCharacterDlgWindow ();
extern void       CreateAttributeDlgWindow ();
extern void       CreateRuleDlgWindow ();
extern void       CreateApplyClassDlgWindow ();
extern void       CreateSpellCheckDlgWindow ();
extern void       CreateMCHARDlgWindow ();
extern void       CreateMathAttribDlgWindow ();
extern void       CreateInitConfirmDlgWindow ();
extern void       CreateInitConfirm3LDlgWindow ();
extern void       CreateChangeFormatDlgWindow ();
extern void       CreateGreekKeyboardDlgWindow ();
extern void       CreateAuthenticationDlgWindow ();
extern void       CreateBackgroundImageDlgWindow ();
extern void       TtaHandleOneEvent ();
extern ThotWindow TtaGetThotWindow ();
extern BinFile    TtaReadOpen ();
extern ThotWindow GetCurrentWindow ();
extern void       WIN_DisplayWords ();
extern void       KbdCallbackHandler ();
extern void       CheckTtCmap ();
#endif /* __STDC__ */

#endif /* _WIN_FCT_ */

==> amaya-src-4.1.tgz: Amaya/thotlib/include/wininclude.h <==
#ifndef _WIN_FCT_
#define _WIN_FCT_
#include <windows.h>
#include "fileaccess.h"

#ifdef __STDC__
extern BOOL       RegisterWin95 (CONST WNDCLASS* lpwc);
extern void       DropFile (Document, View, STRING);
extern HMENU      WIN_GetMenu (int);
extern void       WinErrorBox (ThotWindow, STRING);
extern void       WinLoadGC (HDC, int, int);
extern HFONT      WinLoadFont (HDC, ptrfont);
extern int        WIN_InitSystemColors ();
extern void       WIN_GetDeviceContext (int);
extern void       WIN_ReleaseDeviceContext ();
extern BOOL       WIN_TtaInitDialogue (CHAR_T*);
extern void       WIN_TtaSetPulldownOff (int, ThotMenu, ThotWindow);
extern void       WIN_TtaSetPulldownOn (int, ThotMenu, ThotWindow);
extern void       WIN_TtaSetToggleMenu (int, int, ThotBool, ThotWindow);
extern void       WIN_APP_TextCallback (ThotWindow, int);
extern void       WIN_ThotCallBack (ThotWindow, WPARAM, LPARAM);
extern void       WIN_CharTranslation (ThotWindow, int, UINT, WPARAM, LPARAM);
extern void       WIN_InitDialogueFonts (HDC, CHAR_T*);
extern void       APP_ButtonCallback (ThotButton, int, caddr_t);
extern void       CleanFrameCatList (int);
extern int        GetMainFrameNumber (ThotWindow);
extern LRESULT    ToolBarNotify (int, ThotWindow, WPARAM, LPARAM);
extern int        GetFrameNumber (ThotWindow);
extern void       TtaHandleOneWindowEvent (MSG*);
extern void       CreateOpenImgDlgWindow (ThotWindow parent, STRING imgName, int doc_select, int dir_select, int doc_type);
extern void       WIN_ListSaveDirectory (int, STRING, STRING);
extern void       ThotCallback (int, int, STRING data);
extern void       WIN_TtaSwitchButton (Document, View, int, int, int, BOOL);
extern void       SwitchIconMath (Document, View, ThotBool);
extern void       AddMathButton (Document, View);
extern int        TtaGetMessageTable (CONST CHAR_T*, int msgNumber);
extern int        GetWindowNumber (Document, View view);
extern void       TtaError (int);
extern void       CreateMCHARDlgWindow (ThotWindow parent, STRING math_entity_name) ;
extern void       CreateMathDlgWindow (ThotWindow parent);
extern void       CreateTableDlgWindow (int num_cols, int num_rows, int t_border);
extern void       CreateMatrixDlgWindow (int num_cols, int num_rows);
extern HDC        PASCAL GetPrinterDC (void);
extern void       ReusePrinterDC (void);
extern void       WinInitPrinterColors (void);
extern void       CreateAltDlgWindow ();
extern void       CreateCSSDlgWindow (ThotWindow parent, int nb_item, STRING buffer, STRING title, CHAR_T* msg_text);
extern void       CreateTitleDlgWindow (ThotWindow parent, STRING title);
extern void       CreateHRefDlgWindow (ThotWindow parent, STRING docName, int doc_select, int dir_select, int doc_type);
extern void       CreateHelpDlgWindow (ThotWindow, STRING, STRING, STRING);
extern void       CreatePrintDlgWindow (ThotWindow parent, STRING ps_dir);
extern void       CreateAlign1DlgWindow (ThotWindow, int);
extern void       CreateAlign2DlgWindow (ThotWindow, int);
extern void       CreateAlign3DlgWindow (ThotWindow, int);
extern void       CreateSearchDlgWindow (ThotWindow parent);
extern void       CreateSaveAsDlgWindow (ThotWindow parent, STRING path_name);
extern void       CreateOpenDocDlgWindow (ThotWindow parent, STRING title, STRING docName, int doc_select, int dir_select, int doc_type);
extern void       CreateGraphicsDlgWindow (ThotWindow frame);
extern void       CreateSaveListDlgWindow (ThotWindow parent, int nb_item, STRING save_list);
extern void       CreateCloseDocDlgWindow (ThotWindow parent, STRING msg, ThotBool* save_befor, ThotBool* close_dont_save);
extern void       CreateLanguageDlgWindow (ThotWindow, STRING, STRING, int, STRING, STRING, int, STRING);
extern void       CreateCharacterDlgWindow (ThotWindow, int, int, int, int, int);
extern void       CreateAttributeDlgWindow (STRING, int, int);
extern void       CreateRuleDlgWindow (ThotWindow parent, int nb_class, STRING class_list);
extern void       CreateApplyClassDlgWindow (ThotWindow parent, int nb_class, STRING class_list);
extern void       CreateSpellCheckDlgWindow (ThotWindow, STRING, STRING, int, int, int, int, int, int, int);
extern void       CreateMathAttribDlgWindow (int);
extern void       CreateInitConfirmDlgWindow (ThotWindow, int, STRING, STRING);
extern void       CreateInitConfirm3LDlgWindow (ThotWindow, int, STRING, STRING, STRING, STRING, ThotBool withCancel);
extern void       CreateChangeFormatDlgWindow (int, int, int, int, int, int, int, int);
extern void       CreateGreekKeyboardDlgWindow (ThotWindow);
extern void       CreateAuthenticationDlgWindow (ThotWindow, const STRING, STRING);
extern void       CreateBackgroundImageDlgWindow (ThotWindow parent, STRING image_location);
extern void       CreateMakeIDDlgWindow (ThotWindow parent);
extern void       TtaHandleOneEvent (ThotEvent*);
extern ThotWindow TtaGetThotWindow (int);
extern BinFile    TtaReadOpen (CONST CHAR_T*);
extern ThotWindow GetCurrentWindow ();
extern void       WIN_DisplayWords (void);
extern void       KbdCallbackHandler (ThotWidget, int, caddr_t);
extern void       CheckTtCmap ();

#else  /* __STDC__ */
extern BOOL       RegisterWin95 ();
extern void       DropFile ();
extern HMENU      WIN_GetMenu ();
extern void       WinErrorBox ();
extern void       WinLoadGC ();
extern HFONT      WinLoadFont ();
extern int        WIN_InitSystemColors ();
extern void       WIN_GetDeviceContext ();
extern void       WIN_ReleaseDeviceContext ();
extern BOOL       WIN_TtaInitDialogue ();
extern void       WIN_TtaSetPulldownOff ();
extern void       WIN_TtaSetPulldownOn ();
extern void       WIN_TtaSetToggleMenu ();
extern void       WIN_APP_TextCallback ();
extern void       WIN_ThotCallBack ();
extern void       WIN_CharTranslation ();
extern void       WIN_InitDialogueFonts ();
extern void       APP_ButtonCallback ();
extern void       CleanFrameCatList ();
extern int        GetMainFrameNumber ();
extern LRESULT    ToolBarNotify ();
extern int        GetFrameNumber ();
extern void       TtaHandleOneWindowEvent ();
extern void       CreateOpenImgDlgWindow ();
extern void       CreateTableDlgWindow ();
extern void       WIN_ListSaveDirectory ();
extern void       ThotCallback ();
extern void       WIN_TtaSwitchButton ();
extern void       SwitchIconMath ();
extern void       AddMathButton ();
extern int        TtaGetMessageTable ();
extern int        GetWindowNumber (Document, View);
extern void       TtaError ();
extern void       CreateMatrixDlgWindow ();
extern HDC        PASCAL GetPrinterDC ();
extern void       ReusePrinterDC ();
extern void       WinInitPrinterColors ();
extern void       CreateAltDlgWindow ();
extern void       CreateCSSDlgWindow ();
extern void       CreateTitleDlgWindow ();
extern void       CreateHrefDlgWindow ();
extern void       CreateHelpDlgWindow ();
extern void       CreatePrintDlgWindow ();
extern void       CreateAlign1DlgWindow ();
extern void       CreateAlign2DlgWindow ();
extern void       CreateAlign3DlgWindow ();
extern void       CreateSearchDlgWindow ();
extern void       CreateSaveAsDlgWindow ();
extern void       CreateOpenDocDlgWindow ();
extern void       CreateGraphicsDlgWindow ();
extern void       CreateSaveListDlgWindow ();
extern void       CreateCloseDocDlgWindow ();
extern void       CreateLanguageDlgWindow ();
extern void       CreateCharacterDlgWindow ();
extern void       CreateAttributeDlgWindow ();
extern void       CreateRuleDlgWindow ();
extern void       CreateApplyClassDlgWindow ();
extern void       CreateSpellCheckDlgWindow ();
extern void       CreateMCHARDlgWindow ();
extern void       CreateMathAttribDlgWindow ();
extern void       CreateInitConfirmDlgWindow ();
extern void       CreateInitConfirm3LDlgWindow ();
extern void       CreateChangeFormatDlgWindow ();
extern void       CreateGreekKeyboardDlgWindow ();
extern void       CreateAuthenticationDlgWindow ();
extern void       CreateBackgroundImageDlgWindow ();
extern void       CreateMakeIDDlgWindow ();
extern void       TtaHandleOneEvent ();
extern ThotWindow TtaGetThotWindow ();
extern BinFile    TtaReadOpen ();
extern ThotWindow GetCurrentWindow ();
extern void       WIN_DisplayWords ();
extern void       KbdCallbackHandler ();
extern void       CheckTtCmap ();
#endif /* __STDC__ */

#endif /* _WIN_FCT_ */
